==> rendition-9.4.0.tgz: package/dist_esm5/components/Pager.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import FaChevronLeft from 'react-icons/lib/fa/chevron-left';
import FaChevronRight from 'react-icons/lib/fa/chevron-right';
import { ButtonGroup } from '../';
import Button from './Button';
import { Flex } from './Grid';
import Txt from './Txt';
var Pager = function (_a) {
    var totalItems = _a.totalItems, itemsPerPage = _a.itemsPerPage, page = _a.page, nextPage = _a.nextPage, prevPage = _a.prevPage, props = tslib_1.__rest(_a, ["totalItems", "itemsPerPage", "page", "nextPage", "prevPage"]);
    var lowerBound = page * itemsPerPage;
    var upperBound = Math.min((page + 1) * itemsPerPage, totalItems);
    return (React.createElement(Flex, tslib_1.__assign({ justifyContent: "flex-end", alignItems: "center" }, props),
        React.createElement(Txt, { mr: 2 },
            React.createElement("strong", null,
                lowerBound + 1,
                " - ",
                upperBound),
            ' ',
            "of ",
            React.createElement("strong", null, totalItems)),
        React.createElement(Flex, null,
            React.createElement(ButtonGroup, null,
                React.createElement(Button, { className: "rendition-pager__btn--prev", disabled: totalItems <= itemsPerPage || page <= 0, onClick: function () { return prevPage(); }, icon: React.createElement(FaChevronLeft, null) }),
                React.createElement(Button, { className: "rendition-pager__btn--next", disabled: totalItems <= itemsPerPage ||
                        totalItems / itemsPerPage <= page + 1, onClick: function () { return nextPage(); }, icon: React.createElement(FaChevronRight, null) })))));
};
export default Pager;

==> rendition-9.10.0.tgz: package/dist_esm5/components/Pager.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import FaChevronLeft from 'react-icons/lib/fa/chevron-left';
import FaChevronRight from 'react-icons/lib/fa/chevron-right';
import { ButtonGroup } from '../';
import Button from './Button';
import { Flex } from './Grid';
import Txt from './Txt';
var Pager = function (_a) {
    var totalItems = _a.totalItems, itemsPerPage = _a.itemsPerPage, page = _a.page, nextPage = _a.nextPage, prevPage = _a.prevPage, props = tslib_1.__rest(_a, ["totalItems", "itemsPerPage", "page", "nextPage", "prevPage"]);
    var lowerBound = page * itemsPerPage;
    var upperBound = Math.min((page + 1) * itemsPerPage, totalItems);
    return (React.createElement(Flex, tslib_1.__assign({ justifyContent: "flex-end", alignItems: "center" }, props),
        React.createElement(Txt, { mr: 2 },
            React.createElement("strong", null,
                lowerBound + 1,
                " - ",
                upperBound),
            ' ',
            "of ",
            React.createElement("strong", null, totalItems)),
        React.createElement(Flex, null,
            React.createElement(ButtonGroup, null,
                React.createElement(Button, { quartenary: true, outline: true, className: "rendition-pager__btn--prev", disabled: totalItems <= itemsPerPage || page <= 0, onClick: function () { return prevPage(); }, icon: React.createElement(FaChevronLeft, null) }),
                React.createElement(Button, { quartenary: true, outline: true, className: "rendition-pager__btn--next", disabled: totalItems <= itemsPerPage ||
                        totalItems / itemsPerPage <= page + 1, onClick: function () { return nextPage(); }, icon: React.createElement(FaChevronRight, null) })))));
};
export default Pager;
